# Tools for The Carpentries (Unofficial) 

Trial run for a Python package for The Carpentries.

**This package is a placeholder. It is not currently official!**

## Installation

From the command line, install the package with pip:

```
>> pip install carpentries
```

## Usage

In a Python interpreter:

```
from carpentries import values
```

Or from the command line:

```
carpentries
```
